# shad4fast

*All credits go to <a href="https://x.com/shadcn" target="_blank">@Shadcn</a> for the component styles and <a href="https://x.com/jeremyphoward" target="_blank">@JeremyPHoward</a> for the fastHtml framework.*

[![PyPI - Version](https://img.shields.io/pypi/v/shad4fast.svg)](https://pypi.org/project/shad4fast)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shad4fast.svg)](https://pypi.org/project/shad4fast)

A porting project aiming to bring Shadcn-ui components into FastHtml.

-----

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```console
pip install shad4fast
```

## Usage

```python
from shad4fast import *
```

Refer to the <a href="https://shad4fasthtml.com" target="_blank">Official Site</a> for detailed documentation on each components usage.

## License

`shad4fast` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
